@@ -15,7 +15,7 @@ echo "enum dubVersion = \"$DEB_VERSION\";" >> source/dub/version_.d
 
 echo "Running $GDC..."
 $GDC -v -obin/dub -fversion=DubUseCurl -Isource \
-	-Wl,--push-state,--no-as-needed $LIBS -lz -Wl,--pop-state \
+	$LIBS -lz \
 	$CFLAGS \
 	$LDFLAGS \
 	$* @build-files.txt
